
BEGIN {
  unless ($ENV{RELEASE_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for release candidate testing');
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.05

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'lib/HTML/FormHandler.pm',
    'lib/HTML/FormHandler/Base.pm',
    'lib/HTML/FormHandler/Blocks.pm',
    'lib/HTML/FormHandler/BuildFields.pm',
    'lib/HTML/FormHandler/BuildPages.pm',
    'lib/HTML/FormHandler/Field.pm',
    'lib/HTML/FormHandler/Field/AddElement.pm',
    'lib/HTML/FormHandler/Field/BoolSelect.pm',
    'lib/HTML/FormHandler/Field/Boolean.pm',
    'lib/HTML/FormHandler/Field/Button.pm',
    'lib/HTML/FormHandler/Field/Captcha.pm',
    'lib/HTML/FormHandler/Field/Checkbox.pm',
    'lib/HTML/FormHandler/Field/Compound.pm',
    'lib/HTML/FormHandler/Field/Date.pm',
    'lib/HTML/FormHandler/Field/DateMDY.pm',
    'lib/HTML/FormHandler/Field/DateTime.pm',
    'lib/HTML/FormHandler/Field/Display.pm',
    'lib/HTML/FormHandler/Field/Duration.pm',
    'lib/HTML/FormHandler/Field/Email.pm',
    'lib/HTML/FormHandler/Field/File.pm',
    'lib/HTML/FormHandler/Field/Float.pm',
    'lib/HTML/FormHandler/Field/Hidden.pm',
    'lib/HTML/FormHandler/Field/Hour.pm',
    'lib/HTML/FormHandler/Field/IntRange.pm',
    'lib/HTML/FormHandler/Field/Integer.pm',
    'lib/HTML/FormHandler/Field/Minute.pm',
    'lib/HTML/FormHandler/Field/Money.pm',
    'lib/HTML/FormHandler/Field/Month.pm',
    'lib/HTML/FormHandler/Field/MonthDay.pm',
    'lib/HTML/FormHandler/Field/MonthName.pm',
    'lib/HTML/FormHandler/Field/Multiple.pm',
    'lib/HTML/FormHandler/Field/Nested.pm',
    'lib/HTML/FormHandler/Field/NoValue.pm',
    'lib/HTML/FormHandler/Field/NonEditable.pm',
    'lib/HTML/FormHandler/Field/Password.pm',
    'lib/HTML/FormHandler/Field/PasswordConf.pm',
    'lib/HTML/FormHandler/Field/PosInteger.pm',
    'lib/HTML/FormHandler/Field/PrimaryKey.pm',
    'lib/HTML/FormHandler/Field/Repeatable.pm',
    'lib/HTML/FormHandler/Field/Repeatable/Instance.pm',
    'lib/HTML/FormHandler/Field/Reset.pm',
    'lib/HTML/FormHandler/Field/Result.pm',
    'lib/HTML/FormHandler/Field/RmElement.pm',
    'lib/HTML/FormHandler/Field/Second.pm',
    'lib/HTML/FormHandler/Field/Select.pm',
    'lib/HTML/FormHandler/Field/SelectCSV.pm',
    'lib/HTML/FormHandler/Field/Submit.pm',
    'lib/HTML/FormHandler/Field/Text.pm',
    'lib/HTML/FormHandler/Field/TextArea.pm',
    'lib/HTML/FormHandler/Field/TextCSV.pm',
    'lib/HTML/FormHandler/Field/Upload.pm',
    'lib/HTML/FormHandler/Field/Weekday.pm',
    'lib/HTML/FormHandler/Field/Year.pm',
    'lib/HTML/FormHandler/Fields.pm',
    'lib/HTML/FormHandler/Foo.pm',
    'lib/HTML/FormHandler/I18N.pm',
    'lib/HTML/FormHandler/I18N/ar_kw.pm',
    'lib/HTML/FormHandler/I18N/bg_bg.pm',
    'lib/HTML/FormHandler/I18N/cs_cz.pm',
    'lib/HTML/FormHandler/I18N/de_de.pm',
    'lib/HTML/FormHandler/I18N/en_us.pm',
    'lib/HTML/FormHandler/I18N/hu_hu.pm',
    'lib/HTML/FormHandler/I18N/it_it.pm',
    'lib/HTML/FormHandler/I18N/ja_jp.pm',
    'lib/HTML/FormHandler/I18N/pt_br.pm',
    'lib/HTML/FormHandler/I18N/ru_ru.pm',
    'lib/HTML/FormHandler/I18N/sv_se.pm',
    'lib/HTML/FormHandler/I18N/tr_tr.pm',
    'lib/HTML/FormHandler/I18N/ua_ua.pm',
    'lib/HTML/FormHandler/InitResult.pm',
    'lib/HTML/FormHandler/Manual.pod',
    'lib/HTML/FormHandler/Manual/Catalyst.pod',
    'lib/HTML/FormHandler/Manual/Cookbook.pod',
    'lib/HTML/FormHandler/Manual/Database.pod',
    'lib/HTML/FormHandler/Manual/Defaults.pod',
    'lib/HTML/FormHandler/Manual/Errors.pod',
    'lib/HTML/FormHandler/Manual/Fields.pod',
    'lib/HTML/FormHandler/Manual/FromDFV.pod',
    'lib/HTML/FormHandler/Manual/FromFF.pod',
    'lib/HTML/FormHandler/Manual/InflationDeflation.pod',
    'lib/HTML/FormHandler/Manual/Intro.pod',
    'lib/HTML/FormHandler/Manual/Reference.pod',
    'lib/HTML/FormHandler/Manual/Rendering.pod',
    'lib/HTML/FormHandler/Manual/RenderingCookbook.pod',
    'lib/HTML/FormHandler/Manual/Templates.pod',
    'lib/HTML/FormHandler/Manual/Testing.pod',
    'lib/HTML/FormHandler/Manual/Tutorial.pod',
    'lib/HTML/FormHandler/Manual/Validation.pod',
    'lib/HTML/FormHandler/Merge.pm',
    'lib/HTML/FormHandler/Meta/Role.pm',
    'lib/HTML/FormHandler/Model.pm',
    'lib/HTML/FormHandler/Model/CDBI.pm',
    'lib/HTML/FormHandler/Model/Object.pm',
    'lib/HTML/FormHandler/Moose.pm',
    'lib/HTML/FormHandler/Moose/Role.pm',
    'lib/HTML/FormHandler/Page.pm',
    'lib/HTML/FormHandler/Page/Simple.pm',
    'lib/HTML/FormHandler/Pages.pm',
    'lib/HTML/FormHandler/Params.pm',
    'lib/HTML/FormHandler/Render/RepeatableJs.pm',
    'lib/HTML/FormHandler/Render/Simple.pm',
    'lib/HTML/FormHandler/Render/Table.pm',
    'lib/HTML/FormHandler/Render/Util.pm',
    'lib/HTML/FormHandler/Render/WithTT.pm',
    'lib/HTML/FormHandler/Result.pm',
    'lib/HTML/FormHandler/Result/Role.pm',
    'lib/HTML/FormHandler/Test.pm',
    'lib/HTML/FormHandler/TraitFor/Captcha.pm',
    'lib/HTML/FormHandler/TraitFor/I18N.pm',
    'lib/HTML/FormHandler/TraitFor/Types.pm',
    'lib/HTML/FormHandler/Traits.pm',
    'lib/HTML/FormHandler/Types.pm',
    'lib/HTML/FormHandler/Validate.pm',
    'lib/HTML/FormHandler/Widget/ApplyRole.pm',
    'lib/HTML/FormHandler/Widget/Block.pm',
    'lib/HTML/FormHandler/Widget/Block/Bootstrap.pm',
    'lib/HTML/FormHandler/Widget/Field/Button.pm',
    'lib/HTML/FormHandler/Widget/Field/ButtonTag.pm',
    'lib/HTML/FormHandler/Widget/Field/Captcha.pm',
    'lib/HTML/FormHandler/Widget/Field/Checkbox.pm',
    'lib/HTML/FormHandler/Widget/Field/CheckboxGroup.pm',
    'lib/HTML/FormHandler/Widget/Field/Compound.pm',
    'lib/HTML/FormHandler/Widget/Field/Hidden.pm',
    'lib/HTML/FormHandler/Widget/Field/HorizCheckboxGroup.pm',
    'lib/HTML/FormHandler/Widget/Field/NoRender.pm',
    'lib/HTML/FormHandler/Widget/Field/Password.pm',
    'lib/HTML/FormHandler/Widget/Field/RadioGroup.pm',
    'lib/HTML/FormHandler/Widget/Field/Repeatable.pm',
    'lib/HTML/FormHandler/Widget/Field/Reset.pm',
    'lib/HTML/FormHandler/Widget/Field/Role/HTMLAttributes.pm',
    'lib/HTML/FormHandler/Widget/Field/Role/SelectedOption.pm',
    'lib/HTML/FormHandler/Widget/Field/Select.pm',
    'lib/HTML/FormHandler/Widget/Field/Span.pm',
    'lib/HTML/FormHandler/Widget/Field/Submit.pm',
    'lib/HTML/FormHandler/Widget/Field/Text.pm',
    'lib/HTML/FormHandler/Widget/Field/Textarea.pm',
    'lib/HTML/FormHandler/Widget/Field/Upload.pm',
    'lib/HTML/FormHandler/Widget/Form/Role/HTMLAttributes.pm',
    'lib/HTML/FormHandler/Widget/Form/Simple.pm',
    'lib/HTML/FormHandler/Widget/Form/Table.pm',
    'lib/HTML/FormHandler/Widget/Theme/Bootstrap.pm',
    'lib/HTML/FormHandler/Widget/Theme/Bootstrap3.pm',
    'lib/HTML/FormHandler/Widget/Theme/BootstrapFormMessages.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Base.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Bootstrap.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Bootstrap3.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Fieldset.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/None.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Simple.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/SimpleInline.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Table.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/TableInline.pm',
    'lib/HTML/FormHandler/Wizard.pm'
);

notabs_ok($_) foreach @files;
done_testing;
