
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.18

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/HTML/FormHandler.pm',
    'lib/HTML/FormHandler/Base.pm',
    'lib/HTML/FormHandler/Blocks.pm',
    'lib/HTML/FormHandler/BuildFields.pm',
    'lib/HTML/FormHandler/BuildPages.pm',
    'lib/HTML/FormHandler/Field.pm',
    'lib/HTML/FormHandler/Field/AddElement.pm',
    'lib/HTML/FormHandler/Field/BoolSelect.pm',
    'lib/HTML/FormHandler/Field/Boolean.pm',
    'lib/HTML/FormHandler/Field/Button.pm',
    'lib/HTML/FormHandler/Field/Captcha.pm',
    'lib/HTML/FormHandler/Field/Checkbox.pm',
    'lib/HTML/FormHandler/Field/Compound.pm',
    'lib/HTML/FormHandler/Field/Date.pm',
    'lib/HTML/FormHandler/Field/DateMDY.pm',
    'lib/HTML/FormHandler/Field/DateTime.pm',
    'lib/HTML/FormHandler/Field/Display.pm',
    'lib/HTML/FormHandler/Field/Duration.pm',
    'lib/HTML/FormHandler/Field/Email.pm',
    'lib/HTML/FormHandler/Field/File.pm',
    'lib/HTML/FormHandler/Field/Float.pm',
    'lib/HTML/FormHandler/Field/Hidden.pm',
    'lib/HTML/FormHandler/Field/Hour.pm',
    'lib/HTML/FormHandler/Field/IntRange.pm',
    'lib/HTML/FormHandler/Field/Integer.pm',
    'lib/HTML/FormHandler/Field/Minute.pm',
    'lib/HTML/FormHandler/Field/Money.pm',
    'lib/HTML/FormHandler/Field/Month.pm',
    'lib/HTML/FormHandler/Field/MonthDay.pm',
    'lib/HTML/FormHandler/Field/MonthName.pm',
    'lib/HTML/FormHandler/Field/Multiple.pm',
    'lib/HTML/FormHandler/Field/Nested.pm',
    'lib/HTML/FormHandler/Field/NoValue.pm',
    'lib/HTML/FormHandler/Field/NonEditable.pm',
    'lib/HTML/FormHandler/Field/Password.pm',
    'lib/HTML/FormHandler/Field/PasswordConf.pm',
    'lib/HTML/FormHandler/Field/PosInteger.pm',
    'lib/HTML/FormHandler/Field/PrimaryKey.pm',
    'lib/HTML/FormHandler/Field/Repeatable.pm',
    'lib/HTML/FormHandler/Field/Repeatable/Instance.pm',
    'lib/HTML/FormHandler/Field/Reset.pm',
    'lib/HTML/FormHandler/Field/Result.pm',
    'lib/HTML/FormHandler/Field/RmElement.pm',
    'lib/HTML/FormHandler/Field/Second.pm',
    'lib/HTML/FormHandler/Field/Select.pm',
    'lib/HTML/FormHandler/Field/SelectCSV.pm',
    'lib/HTML/FormHandler/Field/Submit.pm',
    'lib/HTML/FormHandler/Field/Text.pm',
    'lib/HTML/FormHandler/Field/TextArea.pm',
    'lib/HTML/FormHandler/Field/TextCSV.pm',
    'lib/HTML/FormHandler/Field/Upload.pm',
    'lib/HTML/FormHandler/Field/Weekday.pm',
    'lib/HTML/FormHandler/Field/Year.pm',
    'lib/HTML/FormHandler/Fields.pm',
    'lib/HTML/FormHandler/Foo.pm',
    'lib/HTML/FormHandler/I18N.pm',
    'lib/HTML/FormHandler/I18N/ar_kw.pm',
    'lib/HTML/FormHandler/I18N/bg_bg.pm',
    'lib/HTML/FormHandler/I18N/cs_cz.pm',
    'lib/HTML/FormHandler/I18N/de_de.pm',
    'lib/HTML/FormHandler/I18N/en_us.pm',
    'lib/HTML/FormHandler/I18N/hu_hu.pm',
    'lib/HTML/FormHandler/I18N/it_it.pm',
    'lib/HTML/FormHandler/I18N/ja_jp.pm',
    'lib/HTML/FormHandler/I18N/pt_br.pm',
    'lib/HTML/FormHandler/I18N/ru_ru.pm',
    'lib/HTML/FormHandler/I18N/sv_se.pm',
    'lib/HTML/FormHandler/I18N/tr_tr.pm',
    'lib/HTML/FormHandler/I18N/ua_ua.pm',
    'lib/HTML/FormHandler/InitResult.pm',
    'lib/HTML/FormHandler/Manual.pod',
    'lib/HTML/FormHandler/Manual/Catalyst.pod',
    'lib/HTML/FormHandler/Manual/Cookbook.pod',
    'lib/HTML/FormHandler/Manual/Database.pod',
    'lib/HTML/FormHandler/Manual/Defaults.pod',
    'lib/HTML/FormHandler/Manual/Errors.pod',
    'lib/HTML/FormHandler/Manual/Fields.pod',
    'lib/HTML/FormHandler/Manual/FromDFV.pod',
    'lib/HTML/FormHandler/Manual/FromFF.pod',
    'lib/HTML/FormHandler/Manual/InflationDeflation.pod',
    'lib/HTML/FormHandler/Manual/Intro.pod',
    'lib/HTML/FormHandler/Manual/Reference.pod',
    'lib/HTML/FormHandler/Manual/Rendering.pod',
    'lib/HTML/FormHandler/Manual/RenderingCookbook.pod',
    'lib/HTML/FormHandler/Manual/Templates.pod',
    'lib/HTML/FormHandler/Manual/Testing.pod',
    'lib/HTML/FormHandler/Manual/Tutorial.pod',
    'lib/HTML/FormHandler/Manual/Validation.pod',
    'lib/HTML/FormHandler/Merge.pm',
    'lib/HTML/FormHandler/Meta/Role.pm',
    'lib/HTML/FormHandler/Model.pm',
    'lib/HTML/FormHandler/Model/CDBI.pm',
    'lib/HTML/FormHandler/Model/Object.pm',
    'lib/HTML/FormHandler/Moose.pm',
    'lib/HTML/FormHandler/Moose/Role.pm',
    'lib/HTML/FormHandler/Page.pm',
    'lib/HTML/FormHandler/Page/Simple.pm',
    'lib/HTML/FormHandler/Pages.pm',
    'lib/HTML/FormHandler/Params.pm',
    'lib/HTML/FormHandler/Render/RepeatableJs.pm',
    'lib/HTML/FormHandler/Render/Simple.pm',
    'lib/HTML/FormHandler/Render/Table.pm',
    'lib/HTML/FormHandler/Render/Util.pm',
    'lib/HTML/FormHandler/Render/WithTT.pm',
    'lib/HTML/FormHandler/Result.pm',
    'lib/HTML/FormHandler/Result/Role.pm',
    'lib/HTML/FormHandler/Test.pm',
    'lib/HTML/FormHandler/TraitFor/Captcha.pm',
    'lib/HTML/FormHandler/TraitFor/I18N.pm',
    'lib/HTML/FormHandler/TraitFor/Types.pm',
    'lib/HTML/FormHandler/Traits.pm',
    'lib/HTML/FormHandler/Types.pm',
    'lib/HTML/FormHandler/Validate.pm',
    'lib/HTML/FormHandler/Widget/ApplyRole.pm',
    'lib/HTML/FormHandler/Widget/Block.pm',
    'lib/HTML/FormHandler/Widget/Block/Bootstrap.pm',
    'lib/HTML/FormHandler/Widget/Field/Button.pm',
    'lib/HTML/FormHandler/Widget/Field/ButtonTag.pm',
    'lib/HTML/FormHandler/Widget/Field/Captcha.pm',
    'lib/HTML/FormHandler/Widget/Field/Checkbox.pm',
    'lib/HTML/FormHandler/Widget/Field/CheckboxGroup.pm',
    'lib/HTML/FormHandler/Widget/Field/Compound.pm',
    'lib/HTML/FormHandler/Widget/Field/Hidden.pm',
    'lib/HTML/FormHandler/Widget/Field/HorizCheckboxGroup.pm',
    'lib/HTML/FormHandler/Widget/Field/NoRender.pm',
    'lib/HTML/FormHandler/Widget/Field/Password.pm',
    'lib/HTML/FormHandler/Widget/Field/RadioGroup.pm',
    'lib/HTML/FormHandler/Widget/Field/Repeatable.pm',
    'lib/HTML/FormHandler/Widget/Field/Reset.pm',
    'lib/HTML/FormHandler/Widget/Field/Role/HTMLAttributes.pm',
    'lib/HTML/FormHandler/Widget/Field/Role/SelectedOption.pm',
    'lib/HTML/FormHandler/Widget/Field/Select.pm',
    'lib/HTML/FormHandler/Widget/Field/Span.pm',
    'lib/HTML/FormHandler/Widget/Field/Submit.pm',
    'lib/HTML/FormHandler/Widget/Field/Text.pm',
    'lib/HTML/FormHandler/Widget/Field/Textarea.pm',
    'lib/HTML/FormHandler/Widget/Field/Upload.pm',
    'lib/HTML/FormHandler/Widget/Form/Role/HTMLAttributes.pm',
    'lib/HTML/FormHandler/Widget/Form/Simple.pm',
    'lib/HTML/FormHandler/Widget/Form/Table.pm',
    'lib/HTML/FormHandler/Widget/Theme/Bootstrap.pm',
    'lib/HTML/FormHandler/Widget/Theme/Bootstrap3.pm',
    'lib/HTML/FormHandler/Widget/Theme/BootstrapFormMessages.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Base.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Bootstrap.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Bootstrap3.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Fieldset.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/None.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Simple.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/SimpleInline.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/Table.pm',
    'lib/HTML/FormHandler/Widget/Wrapper/TableInline.pm',
    'lib/HTML/FormHandler/Wizard.pm',
    't/01app.t',
    't/author-eol.t',
    't/basic.t',
    't/blocks/basic.t',
    't/blocks/block_list.t',
    't/blocks/blocktags.t',
    't/blocks/loading.t',
    't/blocks/nested.t',
    't/blocks/render_units.t',
    't/bootstrap/basic.t',
    't/bootstrap/control_states.t',
    't/bootstrap/controls.t',
    't/bootstrap/ext_controls.t',
    't/bootstrap/inline.t',
    't/bootstrap/other.t',
    't/bootstrap/search.t',
    't/bootstrap3/basic.t',
    't/bootstrap3/controls.t',
    't/bootstrap3/horiz.t',
    't/bootstrap3/horiz_checkboxgroup.t',
    't/bootstrap3/inlinecheckboxes.t',
    't/bootstrap3/layout_classes.t',
    't/compound/basic.t',
    't/compound/default.t',
    't/compound/empty.t',
    't/compound/include.t',
    't/compound/select.t',
    't/errors/basic.t',
    't/errors/compound.t',
    't/errors/form_messages.t',
    't/errors/messages.t',
    't/errors/req_message.t',
    't/field_setup/checkbox.t',
    't/field_setup/compound_update_fields.t',
    't/field_setup/defaults.t',
    't/field_setup/disabled.t',
    't/field_setup/id.t',
    't/field_setup/inactive.t',
    't/field_setup/init_object.t',
    't/field_setup/input_param.t',
    't/field_setup/missing.t',
    't/field_setup/plus_field.t',
    't/field_setup/update_fields.t',
    't/field_setup/update_subfields.t',
    't/fields/dates.t',
    't/fields/display.t',
    't/fields/fields.t',
    't/fields/float.t',
    't/fields/formhandlerx.t',
    't/fields/novalue.t',
    't/fields/password.t',
    't/fields/repeatable.t',
    't/fields/select.t',
    't/fields/select2.t',
    't/fields/selectcsv.t',
    't/fields/textcsv.t',
    't/form_setup/api.t',
    't/form_setup/clone.t',
    't/form_setup/compound_field_list.t',
    't/form_setup/config.t',
    't/form_setup/dynamic.t',
    't/form_setup/include.t',
    't/form_setup/init_obj.t',
    't/form_setup/no_update.t',
    't/form_setup/posted.t',
    't/form_setup/render_roles.t',
    't/infl_defl/comp_field.t',
    't/infl_defl/default.t',
    't/infl_defl/defl_lives.t',
    't/infl_defl/infl_defl.t',
    't/infl_defl/infl_transform.t',
    't/infl_defl/variations.t',
    't/lib/BookDB/Form/Upload.pm',
    't/lib/Field/Address.pm',
    't/lib/Field/AltText.pm',
    't/lib/Field/MyField.pm',
    't/lib/Form/Address.pm',
    't/lib/Form/AddressRole.pm',
    't/lib/Form/Multiple.pm',
    't/lib/Form/MultipleRole.pm',
    't/lib/Form/NoExtForm.pm',
    't/lib/Form/Person.pm',
    't/lib/Form/PersonRole.pm',
    't/lib/Form/Test.pm',
    't/lib/Form/Two.pm',
    't/lib/MyApp/Component/Section.pm',
    't/lib/MyApp/I18N/abc_de.pm',
    't/lib/Widget/Block/Test.pm',
    't/lib/Widget/Field/Omega.pm',
    't/lib/Widget/Field/TestWidget.pm',
    't/memory_cycles.t',
    't/moose/build_id.t',
    't/moose/composed.t',
    't/moose/field_traits.t',
    't/moose/no_extend.t',
    't/moose/subclass_roles.t',
    't/release-no-tabs.t',
    't/render/actions.t',
    't/render/array.t',
    't/render/basic.t',
    't/render/checkbox.t',
    't/render/checkbox_group.t',
    't/render/classes.t',
    't/render/compound.t',
    't/render/compound2.t',
    't/render/display.t',
    't/render/errors.t',
    't/render/escaping.t',
    't/render/ff.t',
    't/render/filter.t',
    't/render/form_errors.t',
    't/render/get_tag.t',
    't/render/html5_attributes.t',
    't/render/html_attr.t',
    't/render/html_attributes.t',
    't/render/inline.t',
    't/render/label.t',
    't/render/noneditable.t',
    't/render/optgroup.t',
    't/render/radio_group.t',
    't/render/rep_fieldset.t',
    't/render/rep_wrapper.t',
    't/render/repeatable.t',
    't/render/result.t',
    't/render/select.t',
    't/render/simple.t',
    't/render/submit.t',
    't/render/table.t',
    't/render/tags.t',
    't/render/util.t',
    't/render/widget_loading.t',
    't/render/widget_tags.t',
    't/render/widgets.t',
    't/render/with_class.t',
    't/render/withtt.t',
    't/repeatable/defaults.t',
    't/repeatable/empty.t',
    't/repeatable/has_many.t',
    't/repeatable/hash.t',
    't/repeatable/js.t',
    't/repeatable/list.t',
    't/repeatable/nested.t',
    't/repeatable/nested2.t',
    't/repeatable/num_extra.t',
    't/repeatable/reload.t',
    't/repeatable/set_methods.t',
    't/repeatable/subfield.t',
    't/result/basic.t',
    't/result/blocks.t',
    't/result/compound.t',
    't/result/errors.t',
    't/result/repeatable.t',
    't/structured.t',
    't/template.t',
    't/validation/apply.t',
    't/validation/constraints.t',
    't/validation/dependency.t',
    't/validation/filters.t',
    't/validation/reqwhen.t',
    't/validation/types.t',
    't/validation/validate_coderef.t',
    't/validation/when.t',
    't/var/form1.pl',
    't/var/form1.yml',
    't/wizard/basic.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
